##
# File:    ChEMBLTargetMechanismProviderTests.py
# Author:  J. Westbrook
# Date:    15-Jun-2021
#
# Update:
#
#
##
"""
Tests for accessors for ChEMBL target mechanism data.
"""

__docformat__ = "google en"
__author__ = "John Westbrook"
__email__ = "jwest@rcsb.rutgers.edu"
__license__ = "Apache 2.0"

import logging
import os
import unittest

from rcsb.utils.targets.ChEMBLTargetMechanismProvider import ChEMBLTargetMechanismProvider
from rcsb.utils.io.MarshalUtil import MarshalUtil

HERE = os.path.abspath(os.path.dirname(__file__))
TOPDIR = os.path.dirname(os.path.dirname(HERE))

logging.basicConfig(level=logging.INFO, format="%(asctime)s [%(levelname)s]-%(module)s.%(funcName)s: %(message)s")
logger = logging.getLogger()


class ChEMBLTargetMechanismProviderTests(unittest.TestCase):
    skipFull = True

    def setUp(self):
        self.__cachePath = os.path.join(HERE, "test-output", "CACHE")
        self.__mU = MarshalUtil(workPath=self.__cachePath)

    def tearDown(self):
        pass

    def testFetchMechanismData(self):
        try:
            ctP = ChEMBLTargetMechanismProvider(cachePath=self.__cachePath, useCache=False)
            ok = ctP.testCache()
            self.assertFalse(ok)
            #
            tL = ["CHEMBL1987", "CHEMBL3243"]
            ok = ctP.fetchTargetMechanismData(tL, skipExisting=False)
            self.assertTrue(ok)
            ctP.reload()
            ok = ctP.testCache()
            self.assertTrue(ok)

        except Exception as e:
            logger.exception("Failing with %s", str(e))
            self.fail()


def targetMechanismSuite():
    suiteSelect = unittest.TestSuite()
    suiteSelect.addTest(ChEMBLTargetMechanismProviderTests("testFetchMechanismData"))
    return suiteSelect


if __name__ == "__main__":
    mySuite = targetMechanismSuite()
    unittest.TextTestRunner(verbosity=2).run(mySuite)



##
# File:    PharosTargetActivityProviderTests.py
# Author:  J. Westbrook
# Date:    17-Jun-2021
#
# Update:
#
#
##
"""
Tests for accessors for Pharos target activity data.

"""

__docformat__ = "google en"
__author__ = "John Westbrook"
__email__ = "jwest@rcsb.rutgers.edu"
__license__ = "Apache 2.0"

import logging
import os
import unittest

from rcsb.utils.io.FileUtil import FileUtil
from rcsb.utils.targets.PharosTargetActivityProvider import PharosTargetActivityProvider

HERE = os.path.abspath(os.path.dirname(__file__))
TOPDIR = os.path.dirname(os.path.dirname(HERE))

logging.basicConfig(level=logging.INFO, format="%(asctime)s [%(levelname)s]-%(module)s.%(funcName)s: %(message)s")
logger = logging.getLogger()


class PharosTargetActivityProviderTests(unittest.TestCase):
    skipFull = True

    def setUp(self):
        self.__cachePath = os.path.join(HERE, "test-output", "CACHE")
        self.__dirPath = os.path.join(self.__cachePath, "Pharos-target-activity")
        self.__dataPath = os.path.join(HERE, "test-data")
        #
        self.__pharosFixture()

    def tearDown(self):
        pass
        #

    def __pharosFixture(self):
        try:
            ok = False
            fU = FileUtil()
            srcPath = os.path.join(self.__dataPath, "Pharos")
            dstPath = os.path.join(self.__cachePath, "Pharos-targets")
            for fn in ["drug_activity", "cmpd_activity", "protein"]:
                inpPath = os.path.join(srcPath, fn + ".tdd.gz")
                outPath = os.path.join(dstPath, fn + ".tdd.gz")
                fU.get(inpPath, outPath)
                fU.uncompress(outPath, outputDir=dstPath)
                fU.remove(outPath)
            fU.put(os.path.join(srcPath, "pharos-readme.txt"), os.path.join(dstPath, "pharos-readme.txt"))
            ok = True
        except Exception as e:
            logger.exception("Failing with %s", str(e))
            ok = False
        return ok

    def testExportPharosActivity(self):
        try:
            ptP = PharosTargetActivityProvider(cachePath=self.__cachePath, useCache=True)
            ok = ptP.testCache()
            self.assertFalse(ok)
            ok = ptP.fetchTargetActivityData()
            self.assertTrue(ok)
            chIdL = ptP.fetchCompoundIdentifiers()
            self.assertGreaterEqual(len(chIdL), 1000)
            #
            ptP = PharosTargetActivityProvider(cachePath=self.__cachePath, useCache=True)
            ok = ptP.testCache(minCount=1)
            #
            ok = ptP.hasTargetActivity("3707")
            self.assertTrue(ok)
            aL = ptP.getTargetActivity("3707")
            self.assertGreater(len(aL), 40)
            #
        except Exception as e:
            logger.exception("Failing with %s", str(e))
            self.fail()


def pharosTargetActivitySuite():
    suiteSelect = unittest.TestSuite()
    suiteSelect.addTest(PharosTargetActivityProviderTests("testExportPharosActivity"))
    return suiteSelect


if __name__ == "__main__":
    mySuite = pharosTargetActivitySuite()
    unittest.TextTestRunner(verbosity=2).run(mySuite)



##
# File:    PharosTargetProviderTests.py
# Author:  J. Westbrook
# Date:    9-Nov-2020
#
# Update:
#
#
##
"""
Tests for accessors for Pharos target data.

"""

__docformat__ = "google en"
__author__ = "John Westbrook"
__email__ = "jwest@rcsb.rutgers.edu"
__license__ = "Apache 2.0"

import logging
import os
import unittest
import requests

from rcsb.utils.config.ConfigUtil import ConfigUtil
from rcsb.utils.targets.PharosTargetProvider import PharosTargetProvider
from rcsb.utils.io.FileUtil import FileUtil

HERE = os.path.abspath(os.path.dirname(__file__))
TOPDIR = os.path.dirname(os.path.dirname(HERE))

logging.basicConfig(level=logging.INFO, format="%(asctime)s [%(levelname)s]-%(module)s.%(funcName)s: %(message)s")
logger = logging.getLogger()


class PharosTargetProviderTests(unittest.TestCase):
    skipFull = True

    def setUp(self):
        configPath = os.path.join(HERE, "test-data", "pharos-config-example.yml")
        self.__configName = "site_info_configuration"
        self.__cfgOb = ConfigUtil(configPath=configPath, defaultSectionName=self.__configName)
        self.__user = self.__cfgOb.get("_MYSQL_DB_USER_NAME", sectionName=self.__configName)
        self.__pw = self.__cfgOb.get("_MYSQL_DB_PASSWORD", sectionName=self.__configName)
        self.__cachePath = os.path.join(HERE, "test-output", "CACHE")
        self.__dirPath = os.path.join(self.__cachePath, "Pharos-targets")
        self.__dataPath = os.path.join(HERE, "test-data")
        #
        self.__pharosFixture()

    def tearDown(self):
        pass
        #

    def __pharosFixture(self):
        try:
            ok = False
            fU = FileUtil()
            srcPath = os.path.join(self.__dataPath, "Pharos")
            dstPath = self.__dirPath
            for fn in ["drug_activity", "cmpd_activity", "target", "protein", "t2tc"]:
                inpPath = os.path.join(srcPath, fn + ".tdd.gz")
                outPath = os.path.join(dstPath, fn + ".tdd.gz")
                fU.get(inpPath, outPath)
                fU.uncompress(outPath, outputDir=dstPath)
                fU.remove(outPath)
            fU.put(os.path.join(srcPath, "pharos-readme.txt"), os.path.join(dstPath, "pharos-readme.txt"))
            ok = True
        except Exception as e:
            logger.exception("Failing with %s", str(e))
            ok = False
        return ok

    @unittest.skip("Bootstrap test")
    def testBootstrap(self):
        try:
            ptP = PharosTargetProvider(cachePath=self.__cachePath, useCache=False, reloadDb=False)
            configPath = os.path.join(TOPDIR, "rcsb", "mock-data", "config", "dbload-setup-example.yml")
            configName = "site_info_remote_configuration"
            cfgOb = ConfigUtil(configPath=configPath, defaultSectionName=configName)
            ok = ptP.backup(cfgOb, configName)
            self.assertTrue(ok)
        except Exception as e:
            logger.exception("Failing with %s", str(e))
            self.fail()

    @unittest.skipIf(skipFull, "Database dependency")
    def testFetchAndLoadPharosTargets(self):
        try:
            # Now about 630s on macos
            ptP = PharosTargetProvider(cachePath=self.__cachePath, useCache=False, reloadDb=True, fromDb=True, mysqlUser=self.__user, mysqlPassword=self.__pw)
            ok = ptP.testCache()
            self.assertTrue(ok)
        except Exception as e:
            logger.exception("Failing with %s", str(e))
            self.fail()

    @unittest.skipIf(skipFull, "Very long test")
    def testExportPharosTargets(self):
        try:
            ptP = PharosTargetProvider(cachePath=self.__cachePath, useCache=True, reloadDb=False, mysqlUser=self.__user, mysqlPassword=self.__pw)
            ok = ptP.testCache()
            self.assertTrue(ok)
        except Exception as e:
            logger.exception("Failing with %s", str(e))
            self.fail()

    def testExportPharosTargetFasta(self):
        try:
            ptP = PharosTargetProvider(cachePath=self.__cachePath, useCache=True, reloadDb=False)
            ok = ptP.testCache()
            self.assertTrue(ok)
            fastaPath = self.__cachePath = os.path.join(HERE, "test-output", "pharos-targets.fa")
            taxonPath = self.__cachePath = os.path.join(HERE, "test-output", "pharos-targets-taxon.tdd")
            ok = ptP.exportProteinFasta(fastaPath, taxonPath, addTaxonomy=False)
            self.assertTrue(ok)
            #
        except Exception as e:
            logger.exception("Failing with %s", str(e))
            self.fail()

    @unittest.skipIf(skipFull, "Internal test")
    def testStashDependencies(self):
        try:
            ptP = PharosTargetProvider(cachePath=self.__cachePath, useCache=True, reloadDb=False, fromDb=False)
            ok = ptP.testCache()
            self.assertTrue(ok)
            #
            ok = ptP.backup(self.__cfgOb, self.__configName)
            self.assertTrue(ok)
            #
            ok = ptP.restore(self.__cfgOb, self.__configName)
            self.assertTrue(ok)
            #
        except Exception as e:
            logger.exception("Failing with %s", str(e))
            self.fail()

    @unittest.skipIf(skipFull, "Very long test")
    def testExportPharosTargetFastaTax(self):
        try:
            ptP = PharosTargetProvider(cachePath=self.__cachePath, useCache=True, reloadDb=False)
            ok = ptP.testCache()
            self.assertTrue(ok)
            #
            fastaPath = self.__cachePath = os.path.join(HERE, "test-output", "pharos-targets.fa")
            taxonPath = self.__cachePath = os.path.join(HERE, "test-output", "pharos-targets-taxon.tdd")
            ok = ptP.exportProteinFasta(fastaPath, taxonPath, addTaxonomy=True)
            self.assertTrue(ok)
        except Exception as e:
            logger.exception("Failing with %s", str(e))
            self.fail()

    def testPharosDataSite(self):
        try:
            url = "http://habanero.health.unm.edu/tcrd/download/latest.README"
            urlFallback = "https://unmtid-dbs.net/download/TCRD/latest.README"
            ok1 = ok2 = False
            try:
                res = requests.get(url, timeout=30)
                logger.info("Fetch url %r (response %r, len %r)", url, res.status_code, len(res.text))
                ok1 = (res.status_code == 200) and (len(res.text) > 500)
            except Exception:
                logger.error("Failed to fetch Pharos TCRD data from source %r", url)
            #
            res = requests.get(urlFallback, timeout=30)
            logger.info("Fetch fallback url %r (response %r, len %r)", urlFallback, res.status_code, len(res.text))
            ok2 = (res.status_code == 200) and (len(res.text) > 500)
            #
            self.assertTrue(ok1 or ok2)
        except Exception as e:
            logger.exception("Failing with %s", str(e))
            self.fail()


def pharosTargetSuite():
    suiteSelect = unittest.TestSuite()
    suiteSelect.addTest(PharosTargetProviderTests("testFetchPharosTargets"))
    suiteSelect.addTest(PharosTargetProviderTests("testFetchAndLoadPharosTargets"))
    suiteSelect.addTest(PharosTargetProviderTests("testExportPharosTargetFasta"))
    suiteSelect.addTest(PharosTargetProviderTests("testExportPharosTargetFastaTax"))
    suiteSelect.addTest(PharosTargetProviderTests("testPharosDataSite"))
    return suiteSelect


if __name__ == "__main__":
    mySuite = pharosTargetSuite()
    unittest.TextTestRunner(verbosity=2).run(mySuite)



##
# File:    testTargetCofactorDbProvider.py
# Author:  Dennis Piehl
# Date:    20-Aug-2024
# Version: 0.001
#
# Update:
#
#
##
"""
Tests for utilities managing ChEMBL target cofactor data.
"""

__docformat__ = "google en"
__author__ = "Dennis Piehl"
__email__ = "dennis.piehl@rcsb.org"
__license__ = "Apache 2.0"

import logging
import os
import platform
import resource
import time
import unittest

from rcsb.utils.config.ConfigUtil import ConfigUtil
from rcsb.utils.targets.PharosTargetCofactorProvider import PharosTargetCofactorProvider
from rcsb.utils.targets.TargetCofactorDbProvider import TargetCofactorDbProvider

HERE = os.path.abspath(os.path.dirname(__file__))
TOPDIR = os.path.dirname(os.path.dirname(os.path.dirname(HERE)))

logging.basicConfig(level=logging.INFO)
logger = logging.getLogger()


class TargetCofactorDbProviderTests(unittest.TestCase):
    skipTests = False

    def setUp(self):
        self.__cachePath = os.path.join(HERE, "test-output", "CACHE")
        #
        self.__mockTopPath = os.path.join(TOPDIR, "rcsb", "mock-data")
        self.__configPath = os.path.join(self.__mockTopPath, "config", "dbload-setup-example.yml")
        self.__configName = "site_info_configuration"
        self.__cfgOb = ConfigUtil(configPath=self.__configPath, defaultSectionName=self.__configName, mockTopPath=self.__mockTopPath)
        #
        self.__seqMatchResultsPath = os.path.join(HERE, "test-data", "pharos-vs-pdbprent-filtered-results.json.gz")
        self.__startTime = time.time()
        logger.info("Starting %s at %s", self.id(), time.strftime("%Y %m %d %H:%M:%S", time.localtime()))

    def tearDown(self):
        unitS = "MB" if platform.system() == "Darwin" else "GB"
        rusageMax = resource.getrusage(resource.RUSAGE_SELF).ru_maxrss
        logger.info("Maximum resident memory size %.4f %s", rusageMax / 10 ** 6, unitS)
        endTime = time.time()
        logger.info("Completed %s at %s (%.4f seconds)", self.id(), time.strftime("%Y %m %d %H:%M:%S", time.localtime()), endTime - self.__startTime)

    @unittest.skipIf(skipTests, "Partly redundant with testPharosTargetCofactorProvider")
    def testTargetsCofactorsDbPharos(self):
        resourceName = "pharos"
        #
        # First re-load (or re-build) the resource
        stfP = PharosTargetCofactorProvider(cachePath=self.__cachePath, useCache=True)
        ok = stfP.testCache()
        if not ok:
            logger.info("Resource cache not loadable--rebuilding")
            ok = stfP.buildCofactorList(self.__seqMatchResultsPath)
            self.assertTrue(ok)
            stfP = PharosTargetCofactorProvider(cachePath=self.__cachePath, useCache=True)
            ok = stfP.testCache()
        self.assertTrue(ok)
        ok = stfP.hasTarget("5fn7_1")
        self.assertTrue(ok)
        aL = stfP.getTargets("5fn7_1")
        self.assertGreaterEqual(len(aL[0]["cofactors"]), 5)
        #
        # Next test the loading of data to mongo
        tcDbP = TargetCofactorDbProvider(cachePath=self.__cachePath, cfgOb=self.__cfgOb, cofactorResourceName=resourceName)
        okLoad = tcDbP.loadCofactorData(resourceName, stfP)
        logger.info("%r cofactor data DB load status (%r)", resourceName, okLoad)
        numLoaded = tcDbP.cofactorDbCount()
        logger.info("%r cofactor data DB load count (%r)", resourceName, numLoaded)
        ok = numLoaded > 5
        self.assertTrue(ok)
        #
        # Now test access of data in mongo
        tDL = tcDbP.fetchCofactorData("5fn7_1")
        ok = len(tDL) > 0
        self.assertTrue(ok)


def testTargetCofactorDbProviderSuite():
    suiteSelect = unittest.TestSuite()
    suiteSelect.addTest(TargetCofactorDbProviderTests("testTargetsCofactorsDbPharos"))
    return suiteSelect


if __name__ == "__main__":
    mySuite = testTargetCofactorDbProviderSuite()
    unittest.TextTestRunner(verbosity=2).run(mySuite)



##
# File:    DrugBankTargetProviderTests.py
# Author:  J. Westbrook
# Date:    7-Nov-2020
# Version: 0.001
#
# Update:
#
#
##
"""
Tests for utilities managing DrugBank target data.

"""

__docformat__ = "google en"
__author__ = "John Westbrook"
__email__ = "jwest@rcsb.rutgers.edu"
__license__ = "Apache 2.0"

import logging
import os
import platform
import resource
import time
import unittest

from rcsb.utils.targets.DrugBankTargetCofactorProvider import DrugBankTargetCofactorProvider
from rcsb.utils.targets.DrugBankTargetProvider import DrugBankTargetProvider
from rcsb.utils.config.ConfigUtil import ConfigUtil

HERE = os.path.abspath(os.path.dirname(__file__))
TOPDIR = os.path.dirname(os.path.dirname(HERE))

logging.basicConfig(level=logging.INFO)
logger = logging.getLogger()


class DrugBankTargetProviderTests(unittest.TestCase):
    skipFull = True

    def setUp(self):
        configPath = os.path.join(HERE, "test-data", "drugbank-config-example.yml")
        configName = "site_info_configuration"
        cfgOb = ConfigUtil(configPath=configPath, defaultSectionName=configName)
        self.__user = cfgOb.get("_DRUGBANK_AUTH_USERNAME", sectionName=configName)
        self.__pw = cfgOb.get("_DRUGBANK_AUTH_PASSWORD", sectionName=configName)
        self.__cachePath = os.path.join(HERE, "test-output", "CACHE")
        self.__fastaPath = os.path.join(HERE, "test-output", "drugbank-targets.fa")
        self.__taxonPath = os.path.join(HERE, "test-output", "drugbank-targets-taxon.tdd")
        #
        self.__seqMatchResultsPath = os.path.join(HERE, "test-data", "drugbank-vs-pdbprent-filtered-results.json.gz")
        self.__startTime = time.time()
        logger.info("Starting %s at %s", self.id(), time.strftime("%Y %m %d %H:%M:%S", time.localtime()))

    def tearDown(self):
        unitS = "MB" if platform.system() == "Darwin" else "GB"
        rusageMax = resource.getrusage(resource.RUSAGE_SELF).ru_maxrss
        logger.info("Maximum resident memory size %.4f %s", rusageMax / 10 ** 6, unitS)
        endTime = time.time()
        logger.info("Completed %s at %s (%.4f seconds)", self.id(), time.strftime("%Y %m %d %H:%M:%S", time.localtime()), endTime - self.__startTime)

    @unittest.skipIf(skipFull, "Very long test")
    def testAAFetchDrugBankTargets(self):
        dbtP = DrugBankTargetProvider(cachePath=self.__cachePath, useCache=False, username=self.__user, password=self.__pw)
        ok = dbtP.testCache()
        self.assertTrue(ok)
        ok = dbtP.exportFasta(self.__fastaPath, self.__taxonPath, addTaxonomy=False)
        self.assertTrue(ok)

    @unittest.skipIf(skipFull, "Very long test")
    def testBBFetchDrugBankTargetsWithTaxonomy(self):
        dbtP = DrugBankTargetProvider(cachePath=self.__cachePath, useCache=False, username=self.__user, password=self.__pw, addTaxonomy=True)
        ok = dbtP.testCache()
        self.assertTrue(ok)
        ok = dbtP.exportFasta(self.__fastaPath, self.__taxonPath, addTaxonomy=True)
        self.assertTrue(ok)

    @unittest.skipIf(skipFull, "Very long test")
    def testQQBuildDrugBankTargetsFeatures(self):
        #
        stfP = DrugBankTargetCofactorProvider(cachePath=self.__cachePath, useCache=True, fmt="json")
        ok = stfP.buildCofactorList(self.__seqMatchResultsPath)
        self.assertTrue(ok)
        stfP = DrugBankTargetCofactorProvider(cachePath=self.__cachePath, useCache=True, fmt="json")
        ok = stfP.testCache()
        self.assertTrue(ok)
        ok = stfP.hasTarget("5vbn_2")
        self.assertTrue(ok)
        fL = stfP.getTargets("5vbn_2")
        self.assertGreaterEqual(len(fL), 1)


def fetchDrugBankTargets():
    suiteSelect = unittest.TestSuite()
    suiteSelect.addTest(DrugBankTargetProviderTests("testAAFetchDrugBankTargets"))
    suiteSelect.addTest(DrugBankTargetProviderTests("testBBFetchDrugBankTargetsWithTaxonomy"))
    suiteSelect.addTest(DrugBankTargetProviderTests("testQQBuildDrugBankTargetsFeatures"))
    return suiteSelect


if __name__ == "__main__":
    mySuite = fetchDrugBankTargets()
    unittest.TextTestRunner(verbosity=2).run(mySuite)



##
# File:    testCARDTargetOntologyProvider.py
# Author:  D. Piehl
# Date:    14-Mar-2023
# Version: 0.001
#
# Update:
#
#
##
"""
Tests for utilities managing CARD ontology data.

"""

__docformat__ = "google en"
__author__ = "Dennis Piehl"
__email__ = "dennis.piehl@rcsb.org"
__license__ = "Apache 2.0"

import logging
import os
import platform
import resource
import time
import unittest

from rcsb.utils.targets.CARDTargetOntologyProvider import CARDTargetOntologyProvider

HERE = os.path.abspath(os.path.dirname(__file__))
TOPDIR = os.path.dirname(os.path.dirname(HERE))

logging.basicConfig(level=logging.INFO)
logger = logging.getLogger()


class CARDTargetOntologyProviderTests(unittest.TestCase):
    def setUp(self):
        self.__cachePath = os.path.join(HERE, "test-output", "CACHE")
        #
        self.__startTime = time.time()
        logger.info("Starting %s at %s", self.id(), time.strftime("%Y %m %d %H:%M:%S", time.localtime()))

    def tearDown(self):
        unitS = "MB" if platform.system() == "Darwin" else "GB"
        rusageMax = resource.getrusage(resource.RUSAGE_SELF).ru_maxrss
        logger.info("Maximum resident memory size %.4f %s", rusageMax / 10 ** 6, unitS)
        endTime = time.time()
        logger.info("Completed %s at %s (%.4f seconds)", self.id(), time.strftime("%Y %m %d %H:%M:%S", time.localtime()), endTime - self.__startTime)

    def testFetchCARDTargetOntology(self):
        coP = CARDTargetOntologyProvider(cachePath=self.__cachePath, useCache=False)
        ok = coP.buildOntologyData()
        self.assertTrue(ok)
        ok = coP.reload()
        self.assertTrue(ok)
        ok = coP.testCache()
        self.assertTrue(ok)
        #
        coP = None
        coP = CARDTargetOntologyProvider(cachePath=self.__cachePath, useCache=True)
        ok = coP.testCache()
        self.assertTrue(ok)
        aroIdL = ["ARO:3000096", "ARO:3000015", "ARO:3001110", "ARO:0000041", "ARO:0000039", "ARO:3000454"]
        for aroId in aroIdL:
            lineageL = coP.getLineage(aroId)
            logger.info("Lineage list for aroId %s: %r", aroId, lineageL)
            self.assertGreaterEqual(len(lineageL), 2)
        tnL = coP.getTreeNodeList()
        self.assertGreater(len(tnL), 100)
        aroIdL += ["ARO:1000003", "ARO:3000000", "ARO:0000076", "ARO:1000002", "ARO:3000708", "ARO:3000082", "ARO:3000045"]
        for treeNode in tnL:
            if treeNode["id"] in aroIdL:
                logger.info("tree node aroId %s: %r", aroId, treeNode)


def fetchCARDTargetOntology():
    suiteSelect = unittest.TestSuite()
    suiteSelect.addTest(CARDTargetOntologyProviderTests("testFetchCARDTargetOntology"))
    return suiteSelect


if __name__ == "__main__":
    mySuite = fetchCARDTargetOntology()
    unittest.TextTestRunner(verbosity=2).run(mySuite)



##
# File:    ChEMBLTargetActivityProviderTests.py
# Author:  J. Westbrook
# Date:    15-Jun-2021
#
# Update:
#
#
##
"""
Tests for accessors for ChEMBL target activity data.
"""

__docformat__ = "google en"
__author__ = "John Westbrook"
__email__ = "jwest@rcsb.rutgers.edu"
__license__ = "Apache 2.0"

import logging
import os
import unittest

from rcsb.utils.targets.ChEMBLTargetActivityProvider import ChEMBLTargetActivityProvider
from rcsb.utils.io.MarshalUtil import MarshalUtil

HERE = os.path.abspath(os.path.dirname(__file__))
TOPDIR = os.path.dirname(os.path.dirname(HERE))

logging.basicConfig(level=logging.INFO, format="%(asctime)s [%(levelname)s]-%(module)s.%(funcName)s: %(message)s")
logger = logging.getLogger()


class ChEMBLTargetActivityProviderTests(unittest.TestCase):
    skipFull = True

    def setUp(self):
        self.__cachePath = os.path.join(HERE, "test-output", "CACHE")
        self.__mU = MarshalUtil(workPath=self.__cachePath)

    def tearDown(self):
        pass

    def testFetchStatus(self):
        try:
            ctP = ChEMBLTargetActivityProvider(cachePath=self.__cachePath, useCache=False)
            version, releaseDateString = ctP.getStatusDetails()
            if not version:
                logger.warning("status service request failed")
            else:
                self.assertGreaterEqual(int(version), 28)
                self.assertTrue(releaseDateString is not None)
        except Exception as e:
            logger.exception("Failing with %s", str(e))
            self.fail()

    def testFetchMoleculeData(self):
        try:
            ctP = ChEMBLTargetActivityProvider(cachePath=self.__cachePath, useCache=False)
            chemblId = "CHEMBL1421"
            name, inchiKey, _ = ctP.getMoleculeDetails(chemblId)
            self.assertEqual(name, "DASATINIB ANHYDROUS")
            self.assertEqual(inchiKey, "ZBNZXTGUTAYRHI-UHFFFAOYSA-N")
        except Exception as e:
            logger.exception("Failing with %s", str(e))
            self.fail()

    def testFetchActivityDataMulti(self):
        try:
            ctP = ChEMBLTargetActivityProvider(cachePath=self.__cachePath, useCache=False)
            ok = ctP.testCache()
            self.assertFalse(ok)
            #
            tL = ["CHEMBL1987", "CHEMBL3243"]
            ok = ctP.fetchTargetActivityDataMulti(tL, numProc=2)
            self.assertTrue(ok)
            ctP.reload()
            ok = ctP.testCache()
            self.assertTrue(ok)

        except Exception as e:
            logger.exception("Failing with %s", str(e))
            self.fail()

    def testFetchActivityData(self):
        try:
            ctP = ChEMBLTargetActivityProvider(cachePath=self.__cachePath, useCache=False)
            ok = ctP.testCache()
            self.assertFalse(ok)

            mL = ["CHEMBL200117"]
            for chemblId in mL:
                molD = ctP.getMoleculeDetails(chemblId)
                logger.info("%s molD %r", chemblId, molD)
            #
            tL = ["CHEMBL1987", "CHEMBL3243"]
            ok = ctP.fetchTargetActivityData(tL)
            self.assertTrue(ok)
            ctP.reload()
            ok = ctP.testCache()
            self.assertTrue(ok)

        except Exception as e:
            logger.exception("Failing with %s", str(e))
            self.fail()


def targetActivitySuite():
    suiteSelect = unittest.TestSuite()
    suiteSelect.addTest(ChEMBLTargetActivityProviderTests("testFetchStatus"))
    suiteSelect.addTest(ChEMBLTargetActivityProviderTests("testFetchMoleculeData"))
    suiteSelect.addTest(ChEMBLTargetActivityProviderTests("testFetchActivityData"))
    suiteSelect.addTest(ChEMBLTargetActivityProviderTests("testFetchActivityDataMulti"))
    return suiteSelect


if __name__ == "__main__":
    mySuite = targetActivitySuite()
    unittest.TextTestRunner(verbosity=2).run(mySuite)



##
# File:    SAbDabTargetFeatureProviderTests.py
# Author:  J. Westbrook
# Date:    11-Jun-2021
# Version: 0.001
#
# Update:
#
#
##
"""
Tests for utilities managing SAbDab target feature data.
"""

__docformat__ = "google en"
__author__ = "John Westbrook"
__email__ = "jwest@rcsb.rutgers.edu"
__license__ = "Apache 2.0"

import logging
import os
import platform
import resource
import time
import unittest

from rcsb.utils.config.ConfigUtil import ConfigUtil
from rcsb.utils.targets.SAbDabTargetFeatureProvider import SAbDabTargetFeatureProvider

HERE = os.path.abspath(os.path.dirname(__file__))
TOPDIR = os.path.dirname(os.path.dirname(HERE))

logging.basicConfig(level=logging.INFO)
logger = logging.getLogger()


class SAbDabTargetFeatureProviderTests(unittest.TestCase):
    def setUp(self):
        self.__cachePath = os.path.join(HERE, "test-output", "CACHE")
        self.__dataPath = os.path.join(HERE, "test-data")
        #
        self.__seqMatchResultsPath = os.path.join(HERE, "test-data", "sabdab-vs-pdbprent-filtered-results.json.gz")
        self.__startTime = time.time()
        logger.info("Starting %s at %s", self.id(), time.strftime("%Y %m %d %H:%M:%S", time.localtime()))

    def tearDown(self):
        unitS = "MB" if platform.system() == "Darwin" else "GB"
        rusageMax = resource.getrusage(resource.RUSAGE_SELF).ru_maxrss
        logger.info("Maximum resident memory size %.4f %s", rusageMax / 10 ** 6, unitS)
        endTime = time.time()
        logger.info("Completed %s at %s (%.4f seconds)", self.id(), time.strftime("%Y %m %d %H:%M:%S", time.localtime()), endTime - self.__startTime)

    def testBuildSAbDabTargetsFeatures(self):
        stfP = SAbDabTargetFeatureProvider(cachePath=self.__cachePath, useCache=False)
        ok = stfP.testCache()
        self.assertFalse(ok)
        ok = stfP.buildFeatureList(self.__seqMatchResultsPath)
        self.assertTrue(ok)
        stfP = SAbDabTargetFeatureProvider(cachePath=self.__cachePath, useCache=True)
        ok = stfP.testCache()
        self.assertTrue(ok)
        ok = stfP.hasFeatures("4g6k_2")
        self.assertTrue(ok)
        fL = stfP.getFeatures("4g6k_2")
        self.assertGreaterEqual(len(fL), 3)
        # "5bk0|A"
        ok = stfP.hasAssignment("5bk0.A")
        self.assertTrue(ok)
        ok = stfP.getAssignment("5bk0.A", "antigen_name")
        self.assertTrue(ok)

    @unittest.skip("Bootstrap test")
    def testSabdabCacheBootstrap(self):
        try:
            stfP = SAbDabTargetFeatureProvider(cachePath=self.__cachePath, useCache=True)
            ok = stfP.testCache()
            self.assertTrue(ok)
            configPath = os.path.join(self.__dataPath, "sabdab-config.yml")
            configName = "site_info_remote_configuration"
            cfgOb = ConfigUtil(configPath=configPath, defaultSectionName=configName)
            ok = stfP.backup(cfgOb, configName, useGit=True, useStash=True)
            self.assertTrue(ok)
        except Exception as e:
            logger.exception("Failing with %s", str(e))
            self.fail()


def buildSAbDabFeaturesTargets():
    suiteSelect = unittest.TestSuite()
    suiteSelect.addTest(SAbDabTargetFeatureProviderTests("testBuildSAbDabTargetsFeatures"))
    return suiteSelect


if __name__ == "__main__":
    mySuite = buildSAbDabFeaturesTargets()
    unittest.TextTestRunner(verbosity=2).run(mySuite)



##
# File:    ChEMBLTargetProviderTests.py
# Author:  J. Westbrook
# Date:    9-Nov-2020
#
# Update:
#
#
##
"""
Tests for accessors for ChEMBL target data.
"""

__docformat__ = "google en"
__author__ = "John Westbrook"
__email__ = "jwest@rcsb.rutgers.edu"
__license__ = "Apache 2.0"

import logging
import os
import unittest

from chembl_webresource_client.settings import Settings

from rcsb.utils.targets.ChEMBLTargetProvider import ChEMBLTargetProvider
from rcsb.utils.io.MarshalUtil import MarshalUtil

HERE = os.path.abspath(os.path.dirname(__file__))
TOPDIR = os.path.dirname(os.path.dirname(HERE))

Settings.Instance().TIMEOUT = 10  # pylint: disable=no-member
Settings.Instance().MAX_LIMIT = 50  # pylint: disable=no-member
Settings.MAX_LIMIT = 50


logging.basicConfig(level=logging.INFO, format="%(asctime)s [%(levelname)s]-%(module)s.%(funcName)s: %(message)s")
logger = logging.getLogger()


class ChEMBLTargetProviderTests(unittest.TestCase):
    skipFull = True

    def setUp(self):
        self.__cachePath = os.path.join(HERE, "test-output", "CACHE")
        self.__fastaPath = os.path.join(HERE, "test-output", "chembl-targets.fa")
        self.__taxonPath = os.path.join(HERE, "test-output", "chembl-targets-taxon.tdd")
        self.__dataPath = os.path.join(HERE, "test-data")
        self.__mU = MarshalUtil(workPath=self.__cachePath)

    def tearDown(self):
        pass

    def testFetchChEMBLTargets(self):
        try:
            ctP = ChEMBLTargetProvider(cachePath=self.__cachePath, useCache=False)
            ok = ctP.testCache()
            self.assertTrue(ok)
            ok = ctP.exportFasta(self.__fastaPath, self.__taxonPath, addTaxonomy=False)
            self.assertTrue(ok)
        except Exception as e:
            logger.exception("Failing with %s", str(e))
            self.fail()

    def testFetchActivityData(self):
        try:
            logger.info("MAX_LIMIT %r", Settings.Instance().MAX_LIMIT)  # pylint: disable=no-member
            ctP = ChEMBLTargetProvider(cachePath=self.__cachePath, useCache=True)
            ok = ctP.testCache()
            self.assertTrue(ok)
            # P43088|CHEMBL1987|9606
            # P08243|uniprotId|CHEMBL3120|chemblId|9606|taxId
            tL = ["CHEMBL1987", "CHEMBL3120"]
            targetD = ctP.getActivityData(tL)
            ok = self.__mU.doExport(os.path.join(self.__cachePath, "ChEMBL-targets", "chembl-target-activity.json"), targetD, fmt="json", indent=3)
            self.assertTrue(ok)
        except Exception as e:
            logger.exception("Failing with %s", str(e))
            self.fail()

    def testFetchMechanismData(self):
        oD = {}
        try:
            logger.info("MAX_LIMIT %r", Settings.Instance().MAX_LIMIT)  # pylint: disable=no-member
            ctP = ChEMBLTargetProvider(cachePath=self.__cachePath, useCache=True)
            ok = ctP.testCache()
            self.assertTrue(ok)
            # P43088|CHEMBL1987|9606
            # P08243|uniprotId|CHEMBL3120|chemblId|9606|taxId
            tL = ["CHEMBL1987", "CHEMBL3120"]
            oD.update(ctP.getMechanismData(tL))
            #
            ok = self.__mU.doExport(os.path.join(self.__cachePath, "ChEMBL-targets", "chembl-target-mechanism.json"), oD, fmt="json", indent=3)
            self.assertTrue(ok)
        except Exception as e:
            logger.exception("Failing with %s", str(e))
            self.fail()

    #
    @unittest.skipIf(skipFull, "Very long test")
    def testFetchChEMBLTargetsWithTax(self):
        try:
            ctP = ChEMBLTargetProvider(cachePath=self.__cachePath, useCache=True)
            ok = ctP.testCache()
            self.assertTrue(ok)
            ok = ctP.exportFasta(self.__fastaPath, self.__taxonPath, addTaxonomy=True)
            self.assertTrue(ok)
        except Exception as e:
            logger.exception("Failing with %s", str(e))
            self.fail()


def chemblTargetSuite():
    suiteSelect = unittest.TestSuite()
    suiteSelect.addTest(ChEMBLTargetProviderTests("testFetchChEMBLTargets"))
    suiteSelect.addTest(ChEMBLTargetProviderTests("testFetchMechanismData"))
    suiteSelect.addTest(ChEMBLTargetProviderTests("testFetchActivityData"))
    return suiteSelect


if __name__ == "__main__":
    mySuite = chemblTargetSuite()
    unittest.TextTestRunner(verbosity=2).run(mySuite)
